==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Контролна табла",
    "Dashboard app" : "Апликација контролне табле",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Започните свој дан информацијама\n\nNextcloud Контролна табла је почетна тачка вашег дана, она вам даје преглед наредних састанака, хитних и-мејлова, чет порука, придошлих тикета, најновијих твитова и још пуно тога! Корисници могу да додају виџете који им се свиђају и да по жељи измене  позадину.",
    "\"{title} icon\"" : "„{title} икона”",
    "Customize" : "Прилагођавање",
    "Edit widgets" : "Уређивање виџета",
    "Get more widgets from the App Store" : "Преузмите још виџета из Продавнице апликација",
    "Weather service" : "Метео сервис",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ради чувања ваше приватности, временске податке са метеоролошког сервиса у ваше име захтева Nextcloud сервер, тако да се метеоролошком сервису не шаљу лични подаци.",
    "Weather data from Met.no" : "Метеоролошки подаци са Met.no",
    "geocoding with Nominatim" : "геокодирање са Nominatim",
    "elevation data from OpenTopoData" : "висински подаци са OpenTopoData",
    "Weather" : "Време",
    "Status" : "Статус",
    "Good morning" : "Добро јутро",
    "Good morning, {name}" : "Добро јутро, {name}",
    "Good afternoon" : "Добар дан",
    "Good afternoon, {name}" : "Добар дан, {name}",
    "Good evening" : "Добро вече",
    "Good evening, {name}" : "Добро вече, {name}",
    "Hello" : "Здраво",
    "Hello, {name}" : "Здраво, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Започните свој дан информацијама\n\nNextcloud Контролна табла је почетна тачка вашег дана, она вам даје\nпреглед наредних састанака, хитних и-мејлова, чет порука,\nпридошлих тикета, најновијих твитова и још пуно тога! Корисници\nмогу да додају виџете који им се свиђају и да по жељи измене\n позадину.",
    "Change background image" : "Промените слику позадине",
    "Pick from Files" : "Изаберите из Фајлова",
    "Default images" : "Подразумеване слике",
    "Plain background" : "Проста позадина",
    "Insert from {productName}" : "Уметни из {productName}"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Контролна табла",
    "Dashboard app" : "Апликација контролне табле",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Започните свој дан информацијама\n\nNextcloud Контролна табла је почетна тачка вашег дана, она вам даје преглед наредних састанака, хитних и-мејлова, чет порука, придошлих тикета, најновијих твитова и још пуно тога! Људи могу да додају виџете који им се свиђају и да по жељи измене  позадину.",
    "Weather" : "Време",
    "Status" : "Статус",
    "Good morning" : "Добро јутро",
    "Good morning, {name}" : "Добро јутро, {name}",
    "Good afternoon" : "Добар дан",
    "Good afternoon, {name}" : "Добар дан, {name}",
    "Good evening" : "Добро вече",
    "Good evening, {name}" : "Добро вече, {name}",
    "Hello" : "Здраво",
    "Hello, {name}" : "Здраво, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Срећан рођендан 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Срећан рођендан {name} 🥳🤩🎂🎉",
    "Customize" : "Прилагођавање",
    "Edit widgets" : "Уређивање виџета",
    "Get more widgets from the App Store" : "Преузмите још виџета из Продавнице апликација",
    "Weather service" : "Метео сервис",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ради чувања ваше приватности, временске податке са метеоролошког сервиса у ваше име захтева Nextcloud сервер, тако да се метеоролошком сервису не шаљу лични подаци.",
    "Weather data from Met.no" : "Метеоролошки подаци са Met.no",
    "geocoding with Nominatim" : "геокодирање са Nominatim",
    "elevation data from OpenTopoData" : "висински подаци са OpenTopoData"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
